Какво представлява OiRA? | OiRA

Теми

# Какво представлява OiRA?

## Работите с OiRA за пръв път?

Това е кратко въведение в темата за оценката на риска и как OiRA може да ви помогне да управлявате процеса.

## Какво представлява оценката на риска?

Оценката на риска е основа за успешно управление на безопасността и здравето и ключ към намаляването на трудовите злополуки и професионалните заболявания. Ако се изпълнява правилно, тя може да обезпечи подобряване на безопасността и здравето на работното място, както и повишаване на икономическата ефективност като цяло.

Защитата на безопасността и здравето на работещите лица в Европа се извършва чрез оценка и управление на рисковете на работното място. Работодателите са задължени по закон да гарантират безопасността и здравето на работещите във всички аспекти, свързани с работата, и да извършват оценка на риска. От горното следва, че всяко дружество трябва да извърши оценка на риска и да изготви план за действие. За да извършват ефективна оценка на риска на работното място, всички ангажирани с тази дейност лица трябва да разбират добре следните аспекти:

- правния контекст и понятия;
- процеса, чрез който се оценяват рисковете;
- ролята на основните участници в процеса.

Работниците и/или техните представители имат правото да бъдат консултирани относно процедурите за извършване на оценка на риска и участие в нея.

Повече информация за оценката на риска и за участието на работещите и/или техни представители в процеса на оценка на риска можете да намерите на уебсайта на проекта OiRA.

## Какво представлява OiRA?

OiRA означава Интерактивна оценка на риска онлайн. Това е уеб базирано приложение, което ви позволява да извършвате оценка на рисковете за безопасността и здравето на вашето работно място.

## За кого е предназначена OiRA?

OiRA може да се използва от всеки за оценка на свързаните с безопасността и здравето рискове, които може да съществуват на дадено работно място.

OiRA е разработена с оглед да бъде максимално полезна за малките предприятия. OiRA е създадена с конкретната цел да подпомогне тези предприятия в процеса на оценяване на рисковете на работното място и да им помогне да изготвят документирана оценка на риска, включваща план за действие, съобразен с потребностите на предприятието.

## Какво трябва да направя?

Процесът на оценка на риска с помощта на OiRA включва няколко стъпки, които трябва да бъдат изпълнени:

- Подготовка: някои инструменти съдържат въпроси за определяне на профил, които ще ви помогнат да адаптирате инструмента спрямо характеристиките на вашето предприятие. Когато отговаряте на въпросите за определяне на профил, инструментът ще се адаптира към конкретните условия във вашето предприятие и ще покаже приложимите модули.

- Участие: всяка оценка на риска следва да се извършва с активното участие на работниците. Инструментът ви позволява да отпечатате пълния текст на оценката или части от нея, за да предоставите информация на работещите лица и да получите обратна информация от тях.

- Определяне на рисковете: OiRA ще посочи поредица от потенциални опасности или проблеми за безопасността и здравето, които може да са налице на вашето работно място. Отговаряйки на описанията / въпросите с „да“ или „не“, вие посочвате дали са налице такива опасности или проблеми. Можете също да оставите даден въпрос без отговор и да впишете отговора на по-късен етап.

- Оценяване: когато работите с някои инструменти, трябва да подредите по степен на приоритет идентифицираните от вас рискове. Има различни начини за това, които зависят от решенията на нашите национални партньори на OiRA / разработчици на инструменти и възприетия от тях подход. Други инструменти подреждат автоматично рисковете по степен на приоритет, а вие можете да коригирате това подреждане.

- План за действие: за всеки идентифициран риск инструментът ще ви прикани да посочите една или повече мерки за отстраняване или ограничаване на риска. Повечето инструменти ще ви предложат потенциални мерки. Във всички случаи можете да определите мерки по ваш избор.

- Доклад: съгласно закона сте длъжни да документирате извършената от вас оценка на риска. В раздела „Доклад“ ще намерите различни доклади, които ще ви помогнат се ориентирате в отделните етапи на оценката на риска и да изпълните цялостно набелязаните от вас действия / мерки за отстраняване или ограничаване на определените рискове.

## Колко време отнема процедурата?

Не е възможно да се определи колко време е необходимо за изготвяне на оценката, тъй като инструментите, използвани за отделните сектори и в отделните държави, са различни.

За сметка на това можете да отделите за оценката толкова време, с колкото разполагате, и да се върнете към нея при следваща възможност, като продължите от мястото, до което сте стигнали.

## Защо трябва да се регистрирам?

Преди да започнете първата си оценка на риска, трябва да си създадете потребителски акаунт в OiRA — процедурата е лесна и бърза.

Регистрацията ще ви позволи да влизате лесно в системата по всяко време, за да продължите вече започнати оценки или да стартирате нови.

Ако сте регистриран потребител, имате също възможност да разпечатате по всяко време точна и актуална оценка на риска.

## Трябва ли да се подготвя?

Не се нуждаете от каквато и да е конкретна подготовка, за да започнете да използвате инструмента; нужно е обаче да обмислите кой ще извършва оценката и как ще бъде организирано участието на работещите в процеса.

Scroll to top Load toolbar…
Back

## 2-what-is-oira.md

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More